<a {% if id %}id="{{ id }}" {% endif %}target="{{ target }}" action="{{ action }}" method="{% if method != None %}{{method}}{% else %}get{% endif %}" class="octopus-link{% if classes %} {{ classes }}{% endif %}" href="{{ href }}" title="{{ title }}">{{ text }}</a>